@@ -26,11 +26,12 @@ static void atk_no_op_object_factory_class_init (
 
 static AtkObject* atk_no_op_object_factory_create_accessible (
                               GObject                          *obj);
+static GType      atk_no_op_object_factory_get_accessible_type (void);
 
-static AtkNoOpObjectFactoryClass    *parent_class = NULL;
+static gpointer    parent_class = NULL;
 
 GType
-atk_no_op_object_factory_get_type ()
+atk_no_op_object_factory_get_type (void)
 {
   static GType type = 0;
 
@@ -62,9 +63,10 @@ atk_no_op_object_factory_class_init (AtkNoOpObjectFactoryClass *klass)
 {
   AtkObjectFactoryClass *class = ATK_OBJECT_FACTORY_CLASS (klass);
 
-  parent_class = g_type_class_ref (ATK_TYPE_OBJECT_FACTORY);
+  parent_class = g_type_class_peek_parent (klass);
 
   class->create_accessible = atk_no_op_object_factory_create_accessible;
+  class->get_accessible_type = atk_no_op_object_factory_get_accessible_type;
 }
 
 /**
@@ -95,3 +97,9 @@ atk_no_op_object_factory_create_accessible (GObject   *obj)
 
   return accessible;
 }
+
+static GType
+atk_no_op_object_factory_get_accessible_type (void)
+{
+  return ATK_TYPE_NO_OP_OBJECT;
+}
