@@ -34,7 +34,7 @@
 #include "atk-enum-types.h"
 #include "atkintl.h"
 
-GPtrArray *extra_roles = NULL;
+static GPtrArray *extra_roles = NULL;
 
 enum
 {
@@ -154,7 +154,8 @@ static AtkRoleItem role_items [] =
   { ATK_ROLE_PARAGRAPH, N_("paragraph")},
   { ATK_ROLE_APPLICATION, N_("application")},
   { ATK_ROLE_AUTOCOMPLETE, N_("autocomplete")},
-  { ATK_ROLE_EDITBAR, N_("edit bar")}
+  { ATK_ROLE_EDITBAR, N_("edit bar")},
+  { ATK_ROLE_EMBEDDED, N_("embedded component")}
 };
 
 static void            atk_object_class_init        (AtkObjectClass  *klass);
@@ -398,7 +399,7 @@ atk_object_class_init (AtkObjectClass *klass)
   g_object_class_install_property (gobject_class,
                                    PROP_HYPERTEXT_NUM_LINKS,
                                    g_param_spec_int    (atk_object_name_property_hypertext_num_links,
-                                                        _("Accessible Hypertext Number of Links"),
+                                                        _("Number of Accessible Hypertext Links"),
                                                         _("The number of links which the current AtkHypertext has"),
                                                         0,
                                                         G_MAXINT,
@@ -1318,9 +1319,13 @@ atk_role_get_localized_name (AtkRole role)
 #ifdef ENABLE_NLS
   if (!gettext_initialized)
     {
-      gettext_initialized = TRUE;
+      const char *dir = g_getenv ("ATK_ALT_LOCALEDIR");
 
-      bindtextdomain (GETTEXT_PACKAGE, ATK_LOCALEDIR);
+      gettext_initialized = TRUE;
+      if (dir == NULL)
+        dir = ATK_LOCALEDIR;
+
+      bindtextdomain (GETTEXT_PACKAGE, dir);
 #ifdef HAVE_BIND_TEXTDOMAIN_CODESET
       bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 #endif
